@@ -1,9 +1,9 @@
 package Sah::Schema::cryptoexchange::account;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-App-cryp'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [str => {
     summary => 'Account at a cryptocurrency exchange',
@@ -21,22 +21,22 @@ _
     examples => [
         {
             summary => 'Invalid account syntax',
-            data    => 'indodax/a b',
+            value   => 'indodax/a b',
             valid   => 0,
         },
         {
             summary => 'Account too long',
-            data    => 'indodax/'.('a' x 65),
+            value   => 'indodax/'.('a' x 65),
             valid   => 0,
         },
         {
             summary => 'Unknown cryptoexchange',
-            data    => 'foo/acc1',
+            value   => 'foo/acc1',
             valid   => 0,
         },
         {
             summary => 'Valid',
-            data    => 'indodax',
+            value   => 'indodax',
             valid   => 1,
             res     => 'indodax/default',
         },
@@ -58,19 +58,49 @@ Sah::Schema::cryptoexchange::account - Account at a cryptocurrency exchange
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-02.
+This document describes version 0.007 of Sah::Schema::cryptoexchange::account (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("cryptoexchange::account*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['cryptoexchange::account*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- "indodax/a b"  # INVALID (Invalid account syntax)
+ undef  # INVALID (Invalid account syntax)
 
- "indodax/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"  # INVALID (Account too long)
+ undef  # INVALID (Account too long)
 
- "foo/acc1"  # INVALID (Unknown cryptoexchange)
+ undef  # INVALID (Unknown cryptoexchange)
 
- "indodax"  # valid, becomes "indodax/default"
+ undef  # valid, becomes "indodax/default"
 
 =head1 DESCRIPTION
 
